@@ -228,7 +228,7 @@ LANG_INFO = {
         'bidi': False,
         'code': 'hi',
         'name': 'Hindi',
-        'name_local': 'Hindi',
+        'name_local': 'हिंदी',
     },
     'hr': {
         'bidi': False,
@@ -536,6 +536,12 @@ LANG_INFO = {
         'name': 'Urdu',
         'name_local': 'اردو',
     },
+    'uz': {
+        'bidi': False,
+        'code': 'uz',
+        'name': 'Uzbek',
+        'name_local': 'oʻzbek tili',
+    },
     'vi': {
         'bidi': False,
         'code': 'vi',
