@@ -6,7 +6,7 @@ DATE_FORMAT = 'j E Y'
 TIME_FORMAT = 'H:i'
 DATETIME_FORMAT = 'j E Y H:i'
 YEAR_MONTH_FORMAT = 'F Y'
-MONTH_DAY_FORMAT = 'j F'
+MONTH_DAY_FORMAT = 'j E'
 SHORT_DATE_FORMAT = 'd-m-Y'
 SHORT_DATETIME_FORMAT = 'd-m-Y  H:i'
 FIRST_DAY_OF_WEEK = 1  # Monday
